
tailbone-corepos
================

Rattail is a retail software framework, released under the GNU General Public
License.

This package contains software interfaces for the `CORE POS`_ system, which is
open source and freely available.

.. _`CORE POS`: https://www.core-pos.com/

Please see Rattail's `home page`_ for more information.

.. _`home page`: https://rattailproject.org/
